// Libraries
import {PureComponent} from 'react'
import {withRouter, WithRouterProps} from 'react-router'

// APIs
import {postSignout} from 'src/client'

// Constants
import {CLOUD, CLOUD_SIGNOUT_URL} from 'src/shared/constants'

// Components
import {ErrorHandling} from 'src/shared/decorators/errors'

type Props = WithRouterProps

@ErrorHandling
export class Logout extends PureComponent<Props> {
  public componentDidMount() {
    this.handleSignOut()
  }

  public render() {
    return null
  }

  private handleSignOut = async () => {
    if (CLOUD) {
      window.location.href = CLOUD_SIGNOUT_URL
      return
    } else {
      const resp = await postSignout({})

      if (resp.status !== 204) {
        throw new Error(resp.data.message)
      }

      this.props.router.push(`/signin`)
    }
  }
}

export default withRouter<Props>(Logout)
